@@ -2,7 +2,8 @@
 #'
 #' @param year The year for which you are requesting variables.  Either the year of the decennial Census,
 #'             or the endyear for a 5-year ACS sample.
-#' @param dataset One of "sf1", "sf3", "acs5", or "acs5/profile".
+#' @param dataset One of "sf1", "sf3", "acs1", "acs3", "acs5", "acs1/profile", "acs3/profile, "acs5/profile",
+#'                "acs1/subject", "acs3/subject", or "acs5/subject".
 #' @param cache Whether you would like to cache the dataset for future access, or load the dataset
 #'              from an existing cache. Defaults to FALSE.
 #'
@@ -26,6 +27,12 @@ load_variables <- function(year, dataset, cache = FALSE) {
     rds <- gsub("/", "_", rds)
   }
 
+  if (grepl("acs1", dataset)) {
+    if (year %in% 2015:2016) {
+      dataset <- paste0("acs/", dataset)
+    }
+  }
+
   get_dataset <- function(d) {
     set <- paste(as.character(year), d, sep = "/")
 
